Welcome to the ricecooker docs!
===============================


Quickstart
----------
Developers who are new to the ``ricecooker`` library can get started here.

.. toctree::
   :maxdepth: 2

   README <README>
   installation
   usage


Kolibri content platform
------------------------
The Kolibri content platform is described in the following docs, which are intended
to be accessible for both technical and non-technical audiences.

.. toctree::
   :maxdepth: 2

   platform/index


API reference
-------------
The detailed information for content developers (chef authors) is presented here:

.. toctree::
   :maxdepth: 2

   index_api_reference


Tutorial
--------

.. toctree::
   :maxdepth: 2

   tutorial/index



Ricecooker Utils
----------------
The ``ricecooker.utils`` module includes a number of utilities and helper functions
to help chef authors with common extraction and content transformation tasks.

.. toctree::
   :maxdepth: 2
   
   index_utils



Developer docs
--------------
To learn about the inner workings of the ``ricecooker`` library, consult the following:

.. toctree::
   :maxdepth: 2

   developer/index


Module docs
-----------

.. toctree::
   :maxdepth: 1

   modules
   history
